import { EventEmitter } from "../../../stencil-public-runtime";
export declare type Direction = "prev" | "next" | "click-on-tab" | false | null;
export declare class TabContainer {
  private children;
  private tabIds;
  domNode: HTMLUxTabContainerElement;
  /** prop which holds the active tab id */
  activeTabId: string;
  /** when this is true, the tab navigation will not be displayed */
  noNavigation: boolean;
  /** classes to be passed down to the tab-header div, to facilitate integration*/
  tabHeaderClasses: string;
  /** pass in the desired justify-content flexbox value for the alignment of the tab buttons */
  alignTabButtons: string;
  /** if set, the page will scroll so that the tab-header is at the top if the page
   * can be set either to true, and the target element will be the tab header, or a css selector
   * can be used to define the scroll target elememt
   */
  scrollWhenActivated: boolean | string;
  /** if set, will fiix the tab header to the top of the screen upon scrolling past it */
  fixToTop: boolean;
  /** normally, if a "q" parameter is present in the url, the component will try to look for this q
   * parameter value in the content of each tabs, and if a match is found, it will activate that tab.
   * With this property set, the component will not perform any checking on the "q" parameter.
   */
  ignoreSearchParameter: boolean;
  /** if set, the tabs will act like an anchor navigation */
  anchorNavigation: boolean;
  /** when active, the scrollable arrow navigation is enabled */
  arrowNavigationEnabled: boolean;
  /** holds the offset position of the inner div of the scrollable tab-header */
  offset: number;
  /** makes the tab header aware that one of the nav arrows should have disabled styles */
  scrollEnd: "right" | "left";
  /** holds the value of the width of the tab list element, used for styling */
  tabListWidth: number;
  /** flag that indicates if the tab header is in the fixed position */
  tabHeaderFixed: boolean;
  /** holds the value of the tab header width */
  tabHeaderWidth: number;
  /** holds the value of the tab header left offset */
  tabHeaderLeft: number;
  /** the max offset for the scroll of the tab list */
  maxOffset: number;
  /** takes care of passing the correct classes to the navigarion arrows for the shadows */
  tabOverlapping: {
    left: boolean;
    right: boolean;
  };
  private firstVisibleTabIndex;
  private maxTabIndex;
  private tabHeader;
  private tabHeaderHeight;
  private tabHeaderOffsetTop;
  private tabList;
  private tabBody;
  private tabButtons;
  /**
   * unfortunately safary includes margin in the offsetLeft property of the elements.
   * This property detects Safari browsers and fixes this issues detracting the margin
   * for a correct offset calculation
   */
  private isBrowserSafari;
  private isBrowserIE11;
  updateTabButtonName(): void;
  updateNavigation(): void;
  /** event when the active tab was set */
  activeTabEvent: EventEmitter<string>;
  /** id of the tab which will be active */
  setActiveTab(id: string, scroll?: boolean, direction?: Direction): Promise<void>;
  /**
   * PURPOSE: gets the total width of the lab list contaiining the tab buttons
   */
  private getTabListWidth;
  /**
   * CALLED: on component load and on resize events
   * PURPOSE: calculates what the maximum horizontal offset of the
   *          tab list should be
   */
  private updateMaxOffset;
  /**
   * CALLED: whenever there needs to be an horizontal offset chenge of the tab list
   *         trriggered by the arrow navigation or by a resize event.
   *         When there is a click on a tab button, or a click on an external link
   *         that activates a tag, the function in charge of updating the offset is
   *         updateSelectionOffset
   * PURPOSE: scroll the tab list appropriately
   */
  private updateOffset;
  /**
   * CALLED: every time the horizontal offset of the tab list containing the button is
   *         calculated.
   * PURPOSE: it assigns the scroll end of the tab list, either "left" or "right" if the
   *          tab list has reached its maxumum scroll, or null of not.
   */
  private updateScrollEnd;
  /**
   * PURPOSE: calls the appropriate offset calculation function depending on the
   *          direction argument.
   */
  private handleArrowNavigation;
  /**
   * CALLED: when the scroll direction was neither "prev" or "next"
   * PURPOSE: gets the correct first visible element skipping possible
   *          cropped elements, in order to perform follwoing offset calculation
   *          taking as a reference the correct element.
   */
  private updateFirstVisibleTabIndex;
  /** refs of the arrow navigation elements */
  arrowRight: HTMLElement;
  arrowLeft: HTMLElement;
  /** object holding the DOMRects of the arrow navigation elements */
  private arrowsRects;
  /**
   * CALLED: on resize and when there is a function that reqires the rects and
   *         these have not been calculated yet
   * PURPOSE: gets the DOMRects of the arrow navigation elements
   */
  private getArrowsRects;
  /**
   * CALLED: when the arrow navigation is active and there is a click on a tab element
   * PURPOSE: if the clicked tab button is partially covered by the arrow navigation,
   *          it will slide the tab list so that the selected button is fully visible
   */
  private updateSelectionOffset;
  /** traks what action was performed last, helps define tab overlapping styles */
  lastAction: null | "tab-button-click" | "arrow-navigation-click";
  /**
   * CALLLED: when the arrow navigation is active & there is a click on a
   *          navigation arrow or an tab change
   * PURPOSE: manages the overlapping styles of the navigation arrows
   */
  private updateTabOverlapping;
  /** called on resize and on reload, updates the dimension of the tab header
   * element for a correct display of the header fixed state
   */
  private setElementDimensions;
  /** function that activates or deactivates the arrow navigation in the tab
   * header based on the widths of the tab header container and the tab linst
   * containig the tab buttons
   */
  private manageArrowNavigation;
  /**
   * CALLED: whenever a click event occours. Then a check is performed to detect
   *         the presence of the "data-ux-tab-target" attribute on the clicked element.
   * PURPOSE: handles the click click on an element that contains the data-attribute
   *          data-ux-tab-target. The corresponding tab is activated and the a the
   *          scrollToElement function is called.
   */
  private handleLinkClick;
  /** PURPOSE: scrolls to the element: either the tab header or an element defined by
   *          setting the scroll-when-activated prop to a css selector, the function
   *          will try to look for that element and scroll to it.
   *          If the tab header already in the fixed mode, it will scroll to to the
   *          top of the tab body.
   */
  private scrollToElement;
  /**
   * CALLED: on component load.
   * PURPOSE: activates a specific tab is a q parameter with a tab id is present
   *          in the search.
   */
  private activateTabWithSearchParameter;
  /**
   * CALLED: on scroll event
   * PURPOSE: handles the assignment of the fixed state of the tab header
   */
  private handleFixedState;
  /** SCROLL AND RESIZE FUNCTION HANDLERS */
  private onScroll;
  private onResize;
  /** ANCHOR NAVIGATION SPECIFIC FUNCTIONS */
  private anchorNavigationScroll;
  private handleAnchorOnScroll;
  private getTabHeaderHeight;
  /** LIFECYCLE METHODS */
  componentWillLoad(): void;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  render(): any;
}
